package name.nathanmcrae;

import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.fxml.Initializable;
import javafx.scene.input.KeyEvent;
import javafx.scene.input.KeyCode;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.stage.Stage;
import javafx.scene.control.Label;
import javafx.scene.control.TextArea;

import java.net.URL;
import java.util.ResourceBundle;

public class NumbersStationController implements Initializable {
    private Stage settingsStage;

    private Stage selectStationStage;

    @FXML
    private Label lastRetrievedLabel;

    @FXML
    private TextArea messageTextArea;

    @FXML
    private void handleSettingsButtonPress() {
        System.out.println("Button pressed!");
        lastRetrievedLabel.setText("Button pressed!");

        if (settingsStage == null || !settingsStage.isShowing()) {
            try {
                FXMLLoader fxmlLoader = new FXMLLoader(getClass().getResource("NumbersStationSettings.fxml"));
                Parent root = fxmlLoader.load();
                settingsStage = new Stage();
                settingsStage.setTitle("Numbers Station Settings");
                settingsStage.setScene(new Scene(root));
                settingsStage.show();
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            settingsStage.toFront();
        }
    }

    @FXML
    private void handleSelectStationButtonPress() {
        if (selectStationStage == null || !selectStationStage.isShowing()) {
            try {
                FXMLLoader fxmlLoader = new FXMLLoader(getClass().getResource("NumbersStationSelection.fxml"));
                Parent root = fxmlLoader.load();
                selectStationStage = new Stage();
                selectStationStage.setTitle("Numbers Station Selection");
                selectStationStage.setScene(new Scene(root));
                selectStationStage.show();
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            selectStationStage.toFront();
        }
    }

    @Override
    public void initialize(URL location, ResourceBundle resources) {
        messageTextArea.addEventFilter(KeyEvent.ANY, event -> {
            int cursorPosition = messageTextArea.getCaretPosition();

            String character = event.getCharacter();
            KeyCode code = event.getCode();

            String str = event.getText();

            // Consume the event to block the default behavior
            if (!(code == KeyCode.LEFT ||
                  code == KeyCode.RIGHT ||
                  code == KeyCode.UP ||
                  code == KeyCode.DOWN ||
                  code == KeyCode.HOME ||
                  code == KeyCode.END ||
                  code == KeyCode.PAGE_UP ||
                  code == KeyCode.PAGE_DOWN)) {
                event.consume();
            }

            if (event.getEventType() == KeyEvent.KEY_PRESSED &&
                (code == KeyCode.DIGIT0 ||
                 code == KeyCode.DIGIT1 ||
                 code == KeyCode.DIGIT2 ||
                 code == KeyCode.DIGIT3 ||
                 code == KeyCode.DIGIT4 ||
                 code == KeyCode.DIGIT5 ||
                 code == KeyCode.DIGIT6 ||
                 code == KeyCode.DIGIT7 ||
                 code == KeyCode.DIGIT8 ||
                 code == KeyCode.DIGIT9)) {

                if (cursorPosition < messageTextArea.getLength()) {
                    char currentChar = messageTextArea.getText().charAt(cursorPosition);
                    if (Character.isWhitespace(currentChar)) {
                        messageTextArea.replaceText(cursorPosition + 1, cursorPosition + 2, str);
                    } else {
                        messageTextArea.replaceText(cursorPosition, cursorPosition + 1, str);
                    }
                }
            }
        });
    }
}
